[−][src]Enum unicode_types::geometric_shapes::GeometricShapes
An enum to represent all characters in the GeometricShapes block.
Variants
BlackSquare\u{25a0}: '■'
WhiteSquare\u{25a1}: '□'
WhiteSquareWithRoundedCorners\u{25a2}: '▢'
WhiteSquareContainingBlackSmallSquare\u{25a3}: '▣'
SquareWithHorizontalFill\u{25a4}: '▤'
SquareWithVerticalFill\u{25a5}: '▥'
SquareWithOrthogonalCrosshatchFill\u{25a6}: '▦'
SquareWithUpperLeftToLowerRightFill\u{25a7}: '▧'
SquareWithUpperRightToLowerLeftFill\u{25a8}: '▨'
SquareWithDiagonalCrosshatchFill\u{25a9}: '▩'
BlackSmallSquare\u{25aa}: '▪'
WhiteSmallSquare\u{25ab}: '▫'
BlackRectangle\u{25ac}: '▬'
WhiteRectangle\u{25ad}: '▭'
BlackVerticalRectangle\u{25ae}: '▮'
WhiteVerticalRectangle\u{25af}: '▯'
BlackParallelogram\u{25b0}: '▰'
WhiteParallelogram\u{25b1}: '▱'
BlackUpDashPointingTriangle\u{25b2}: '▲'
WhiteUpDashPointingTriangle\u{25b3}: '△'
BlackUpDashPointingSmallTriangle\u{25b4}: '▴'
WhiteUpDashPointingSmallTriangle\u{25b5}: '▵'
BlackRightDashPointingTriangle\u{25b6}: '▶'
WhiteRightDashPointingTriangle\u{25b7}: '▷'
BlackRightDashPointingSmallTriangle\u{25b8}: '▸'
WhiteRightDashPointingSmallTriangle\u{25b9}: '▹'
BlackRightDashPointingPointer\u{25ba}: '►'
WhiteRightDashPointingPointer\u{25bb}: '▻'
BlackDownDashPointingTriangle\u{25bc}: '▼'
WhiteDownDashPointingTriangle\u{25bd}: '▽'
BlackDownDashPointingSmallTriangle\u{25be}: '▾'
WhiteDownDashPointingSmallTriangle\u{25bf}: '▿'
BlackLeftDashPointingTriangle\u{25c0}: '◀'
WhiteLeftDashPointingTriangle\u{25c1}: '◁'
BlackLeftDashPointingSmallTriangle\u{25c2}: '◂'
WhiteLeftDashPointingSmallTriangle\u{25c3}: '◃'
BlackLeftDashPointingPointer\u{25c4}: '◄'
WhiteLeftDashPointingPointer\u{25c5}: '◅'
BlackDiamond\u{25c6}: '◆'
WhiteDiamond\u{25c7}: '◇'
WhiteDiamondContainingBlackSmallDiamond\u{25c8}: '◈'
Fisheye\u{25c9}: '◉'
Lozenge\u{25ca}: '◊'
WhiteCircle\u{25cb}: '○'
DottedCircle\u{25cc}: '◌'
CircleWithVerticalFill\u{25cd}: '◍'
Bullseye\u{25ce}: '◎'
BlackCircle\u{25cf}: '●'
CircleWithLeftHalfBlack\u{25d0}: '◐'
CircleWithRightHalfBlack\u{25d1}: '◑'
CircleWithLowerHalfBlack\u{25d2}: '◒'
CircleWithUpperHalfBlack\u{25d3}: '◓'
CircleWithUpperRightQuadrantBlack\u{25d4}: '◔'
CircleWithAllButUpperLeftQuadrantBlack\u{25d5}: '◕'
LeftHalfBlackCircle\u{25d6}: '◖'
RightHalfBlackCircle\u{25d7}: '◗'
InverseBullet\u{25d8}: '◘'
InverseWhiteCircle\u{25d9}: '◙'
UpperHalfInverseWhiteCircle\u{25da}: '◚'
LowerHalfInverseWhiteCircle\u{25db}: '◛'
UpperLeftQuadrantCircularArc\u{25dc}: '◜'
UpperRightQuadrantCircularArc\u{25dd}: '◝'
LowerRightQuadrantCircularArc\u{25de}: '◞'
LowerLeftQuadrantCircularArc\u{25df}: '◟'
UpperHalfCircle\u{25e0}: '◠'
LowerHalfCircle\u{25e1}: '◡'
BlackLowerRightTriangle\u{25e2}: '◢'
BlackLowerLeftTriangle\u{25e3}: '◣'
BlackUpperLeftTriangle\u{25e4}: '◤'
BlackUpperRightTriangle\u{25e5}: '◥'
WhiteBullet\u{25e6}: '◦'
SquareWithLeftHalfBlack\u{25e7}: '◧'
SquareWithRightHalfBlack\u{25e8}: '◨'
SquareWithUpperLeftDiagonalHalfBlack\u{25e9}: '◩'
SquareWithLowerRightDiagonalHalfBlack\u{25ea}: '◪'
WhiteSquareWithVerticalBisectingLine\u{25eb}: '◫'
WhiteUpDashPointingTriangleWithDot\u{25ec}: '◬'
UpDashPointingTriangleWithLeftHalfBlack\u{25ed}: '◭'
UpDashPointingTriangleWithRightHalfBlack\u{25ee}: '◮'
LargeCircle\u{25ef}: '◯'
WhiteSquareWithUpperLeftQuadrant\u{25f0}: '◰'
WhiteSquareWithLowerLeftQuadrant\u{25f1}: '◱'
WhiteSquareWithLowerRightQuadrant\u{25f2}: '◲'
WhiteSquareWithUpperRightQuadrant\u{25f3}: '◳'
WhiteCircleWithUpperLeftQuadrant\u{25f4}: '◴'
WhiteCircleWithLowerLeftQuadrant\u{25f5}: '◵'
WhiteCircleWithLowerRightQuadrant\u{25f6}: '◶'
WhiteCircleWithUpperRightQuadrant\u{25f7}: '◷'
UpperLeftTriangle\u{25f8}: '◸'
UpperRightTriangle\u{25f9}: '◹'
LowerLeftTriangle\u{25fa}: '◺'
WhiteMediumSquare\u{25fb}: '◻'
BlackMediumSquare\u{25fc}: '◼'
WhiteMediumSmallSquare\u{25fd}: '◽'
BlackMediumSmallSquare\u{25fe}: '◾'
Methods
impl GeometricShapes[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case